@@ -28,13 +28,21 @@ struct Args {
 	/// what plugins to not run
 	#[argh(option, short = 'i')]
 	ignored_plugins: Vec<String>,
+
+	/// whether to output debug stuff
+	#[argh(switch, short = 'v')]
+	verbose: bool,
 }
 
 fn main() {
-	minifemme::start(minifemme::LevelFilter::Info, minifemme::LogMode::Pretty);
+	let args: Args = argh::from_env();
+	if args.verbose {
+		minifemme::start(minifemme::LevelFilter::Trace, minifemme::LogMode::Pretty);
+	} else {
+		minifemme::start(minifemme::LevelFilter::Info, minifemme::LogMode::Pretty);
+	}
 	info!("Starting build");
 	let start = Instant::now();
-	let args: Args = argh::from_env();
 	let mut sh = Shtola::new();
 	sh.source(args.source);
 	sh.destination(args.destination);
